@@ -1,6 +1,6 @@
 use utf8;
 package CatalystX::InjectModule::MI;
-$CatalystX::InjectModule::MI::VERSION = '0.11';
+$CatalystX::InjectModule::MI::VERSION = '0.12';
 # This plugin is inspired by :
 # - CatalystX::InjectComponent
 # - Catalyst::Plugin::AutoCRUD
@@ -8,7 +8,7 @@ $CatalystX::InjectModule::MI::VERSION = '0.11';
 # - Catalyst::Plugin::Thruk::ConfigLoader
 
 use Class::Load ':all';
-use Clone 'clone';
+use Data::Clone 'clone';
 use File::Find;
 use File::Basename qw( dirname );
 use File::Path qw( make_path );
@@ -320,7 +320,7 @@ sub uninstall_module {
 
     if ( -f $module_file ) {
         load_class($module_name);
-        my $mod = $module_name->new;
+        my $mod = $module_name->new(mi => $self);
         if ( $mod->can('uninstall') ) {
             $self->log("  - UnInstall $module_name $module_file...");
             $mod->uninstall($module, $self);
@@ -514,7 +514,7 @@ CatalystX::InjectModule::MI Catalyst Module injector
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
